@@ -43,7 +43,7 @@ class Argument(Option):
     arg_action: str
     # Arguments that the option can take, like ("-p", "--player"), if it's
     # available for the argument parser. Otherwise, it's None.
-    args: Tuple[str]
+    args: Tuple[str, ...]
 
 
 @dataclass
@@ -73,7 +73,7 @@ OPTIONS = {
 
     # Custom config file, only available for the argument parser.
     'config_file': Argument(
-        description=f"the config file path.",
+        description="the config file path.",
         type=str,
         default=DEFAULT_PATH,
         args=('--config-file',),
